# Changelog

## 0.16.0 (2025-03-18)

Full Changelog: [v0.15.2...v0.16.0](https://github.com/propulsion-ai/propulsionai-python/compare/v0.15.2...v0.16.0)

### Features

* upgrade and remove proxies ([7743603](https://github.com/propulsion-ai/propulsionai-python/commit/774360300c06590859663086b9d98cad1dfbd3a6))

## 0.15.3 (2025-03-18)

Full Changelog: [v0.15.2...v0.15.3](https://github.com/propulsion-ai/propulsionai-python/compare/v0.15.2...v0.15.3)
## 0.15.2 (2024-12-03)

Full Changelog: [v0.15.1...v0.15.2](https://github.com/propulsion-ai/propulsionai-python/compare/v0.15.1...v0.15.2)

### Features

* fix lint ([95d9877](https://github.com/propulsion-ai/propulsionai-python/commit/95d98770170a03afcbf30ad17a2bea87906cc4b5))
* fix model/deployment ([e49f6f8](https://github.com/propulsion-ai/propulsionai-python/commit/e49f6f85cb75f5b262450724ef06100667940004))
* linting ([385b1a2](https://github.com/propulsion-ai/propulsionai-python/commit/385b1a2a1968182ab9fa7ba828f436d722f3db2d))

## 0.15.1 (2024-08-24)

Full Changelog: [v0.15.0...v0.15.1](https://github.com/propulsion-ai/propulsionai-python/compare/v0.15.0...v0.15.1)

### Features

* **api:** OpenAPI spec update via Stainless API ([#112](https://github.com/propulsion-ai/propulsionai-python/issues/112)) ([2b1aae7](https://github.com/propulsion-ai/propulsionai-python/commit/2b1aae7451cf6d80954c44486f87b5603cddba5f))


### Chores

* **internal:** codegen related update ([#110](https://github.com/propulsion-ai/propulsionai-python/issues/110)) ([1f2fb8b](https://github.com/propulsion-ai/propulsionai-python/commit/1f2fb8b96e1c8ac56b52bc6c7f068aba1c0c98f0))

## 0.15.0 (2024-08-23)

Full Changelog: [v0.14.0...v0.15.0](https://github.com/propulsion-ai/propulsionai-python/compare/v0.14.0...v0.15.0)

### Features

* add run_tools ability with streaming ([f70a0e0](https://github.com/propulsion-ai/propulsionai-python/commit/f70a0e0f9edb15e12f6e7ec44732fe205544e94f))
* add run_tools ability with streaming ([084f2bc](https://github.com/propulsion-ai/propulsionai-python/commit/084f2bcfcfe25c7f1b89823bbb70cf2d580344be))
* lint and fix examples ([1ca1cb4](https://github.com/propulsion-ai/propulsionai-python/commit/1ca1cb4319f28e213c45ae100f8c3b888b817044))
* lint and fix examples ([b4dceb7](https://github.com/propulsion-ai/propulsionai-python/commit/b4dceb770dcea2d57aeb2525f6690aeba792d333))
* lint and fix examples ([6ffd494](https://github.com/propulsion-ai/propulsionai-python/commit/6ffd4940ebb403aeb42575742d1481b3d1fd34d8))

## 0.14.0 (2024-08-01)

Full Changelog: [v0.13.0...v0.14.0](https://github.com/propulsion-ai/propulsionai-python/compare/v0.13.0...v0.14.0)

### Features

* stream false in test fix and lint ([894636b](https://github.com/propulsion-ai/propulsionai-python/commit/894636b00c714acaf19585863ffb9621f30be2ac))

## 0.13.0 (2024-08-01)

Full Changelog: [v0.12.0...v0.13.0](https://github.com/propulsion-ai/propulsionai-python/compare/v0.12.0...v0.13.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#101](https://github.com/propulsion-ai/propulsionai-python/issues/101)) ([15009f6](https://github.com/propulsion-ai/propulsionai-python/commit/15009f672bcb667b7cebc36b66ee4370dfbdf76b))
* **api:** update via SDK Studio ([#103](https://github.com/propulsion-ai/propulsionai-python/issues/103)) ([02d077b](https://github.com/propulsion-ai/propulsionai-python/commit/02d077b739aca441825df8bf99dfa9eb1355eb63))

## 0.12.0 (2024-07-31)

Full Changelog: [v0.11.0...v0.12.0](https://github.com/propulsion-ai/propulsionai-python/compare/v0.11.0...v0.12.0)

### Features

* **api:** update via SDK Studio ([#99](https://github.com/propulsion-ai/propulsionai-python/issues/99)) ([9b163f2](https://github.com/propulsion-ai/propulsionai-python/commit/9b163f2241fadc8c3fe6aefc053a8f488c523929))


### Chores

* **internal:** add type construction helper ([#97](https://github.com/propulsion-ai/propulsionai-python/issues/97)) ([f982297](https://github.com/propulsion-ai/propulsionai-python/commit/f982297b09fb384d1bf1f39c15442a0d78fe92ba))

## 0.11.0 (2024-07-29)

Full Changelog: [v0.10.0...v0.11.0](https://github.com/propulsion-ai/propulsionai-python/compare/v0.10.0...v0.11.0)

### Features

* **api:** update via SDK Studio ([#94](https://github.com/propulsion-ai/propulsionai-python/issues/94)) ([2434930](https://github.com/propulsion-ai/propulsionai-python/commit/2434930eab45b5e1a1a27095d898c417af54c5c7))


### Chores

* **internal:** add type construction helper ([#93](https://github.com/propulsion-ai/propulsionai-python/issues/93)) ([805faeb](https://github.com/propulsion-ai/propulsionai-python/commit/805faebf5e3adac19e3f4137c8cbdb0e71b5a679))

## 0.10.0 (2024-07-29)

Full Changelog: [v0.9.0...v0.10.0](https://github.com/propulsion-ai/propulsionai-python/compare/v0.9.0...v0.10.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#89](https://github.com/propulsion-ai/propulsionai-python/issues/89)) ([7f67e47](https://github.com/propulsion-ai/propulsionai-python/commit/7f67e47d2a7967b7276021526a7561aa455e04c2))

## 0.9.0 (2024-07-29)

Full Changelog: [v0.8.0...v0.9.0](https://github.com/propulsion-ai/propulsionai-python/compare/v0.8.0...v0.9.0)

### Features

* fix response id type ([61755f7](https://github.com/propulsion-ai/propulsionai-python/commit/61755f776e663d81e064e698a17dd30a1925883f))

## 0.8.0 (2024-07-29)

Full Changelog: [v0.7.0...v0.8.0](https://github.com/propulsion-ai/propulsionai-python/compare/v0.7.0...v0.8.0)

### Features

* **api:** update via SDK Studio ([#84](https://github.com/propulsion-ai/propulsionai-python/issues/84)) ([83d426a](https://github.com/propulsion-ai/propulsionai-python/commit/83d426aff36686fd2407bf58ea29a1676cb9b35a))

## 0.7.0 (2024-07-29)

Full Changelog: [v0.6.0...v0.7.0](https://github.com/propulsion-ai/propulsionai-python/compare/v0.6.0...v0.7.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#81](https://github.com/propulsion-ai/propulsionai-python/issues/81)) ([2d77ba9](https://github.com/propulsion-ai/propulsionai-python/commit/2d77ba9e1dd9246e319a15c3dfb9ccc337c89675))

## 0.6.0 (2024-07-29)

Full Changelog: [v0.5.0...v0.6.0](https://github.com/propulsion-ai/propulsionai-python/compare/v0.5.0...v0.6.0)

### Features

* **api:** update via SDK Studio ([#78](https://github.com/propulsion-ai/propulsionai-python/issues/78)) ([867e08c](https://github.com/propulsion-ai/propulsionai-python/commit/867e08c54e3679d831af6c5ea1e41eec5c302b75))

## 0.5.0 (2024-07-29)

Full Changelog: [v0.4.0...v0.5.0](https://github.com/propulsion-ai/propulsionai-python/compare/v0.4.0...v0.5.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#75](https://github.com/propulsion-ai/propulsionai-python/issues/75)) ([b8ed847](https://github.com/propulsion-ai/propulsionai-python/commit/b8ed847e75c6d3a80ef2416f79e0f7677f24f0a7))

## 0.4.0 (2024-07-26)

Full Changelog: [v0.3.0...v0.4.0](https://github.com/propulsion-ai/propulsionai-python/compare/v0.3.0...v0.4.0)

### Features

* attempt lint and test fix ([c5d697d](https://github.com/propulsion-ai/propulsionai-python/commit/c5d697d4251c4e523eec0f9e23b08e07044e7233))
* attempt lint and test fix ([8ceb59a](https://github.com/propulsion-ai/propulsionai-python/commit/8ceb59aa444b3f0d384defb59a7a5d6b7bdb43aa))

## 0.3.0 (2024-07-26)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/propulsion-ai/propulsionai-python/compare/v0.2.0...v0.3.0)

### Features

* add examples and lint ([8e4e2e7](https://github.com/propulsion-ai/propulsionai-python/commit/8e4e2e788285b819dacb76f5e74980a0f33d4d37))


### Chores

* **internal:** version bump ([#70](https://github.com/propulsion-ai/propulsionai-python/issues/70)) ([ea906ea](https://github.com/propulsion-ai/propulsionai-python/commit/ea906eab75eba4657adbc18bc2ce702839bcd880))

## 0.2.0 (2024-07-25)

Full Changelog: [v0.1.0-alpha.12...v0.2.0](https://github.com/propulsion-ai/propulsionai-python/compare/v0.1.0-alpha.12...v0.2.0)

### Features

* **api:** OpenAPI spec update via Stainless API ([#61](https://github.com/propulsion-ai/propulsionai-python/issues/61)) ([802a176](https://github.com/propulsion-ai/propulsionai-python/commit/802a176edc3f1b01493775cc71d7240167e43f64))
* **api:** OpenAPI spec update via Stainless API ([#62](https://github.com/propulsion-ai/propulsionai-python/issues/62)) ([d22c581](https://github.com/propulsion-ai/propulsionai-python/commit/d22c581f5fc81619fa0de99fb9bdf8531a896951))
* **api:** OpenAPI spec update via Stainless API ([#63](https://github.com/propulsion-ai/propulsionai-python/issues/63)) ([15b039b](https://github.com/propulsion-ai/propulsionai-python/commit/15b039b53d929fbe268d3373a03ff51efe2fe64f))
* **api:** OpenAPI spec update via Stainless API ([#65](https://github.com/propulsion-ai/propulsionai-python/issues/65)) ([f0ee52f](https://github.com/propulsion-ai/propulsionai-python/commit/f0ee52f4d571a5d9ebd3164f73d8323c0141bf3e))
* **api:** OpenAPI spec update via Stainless API ([#67](https://github.com/propulsion-ai/propulsionai-python/issues/67)) ([1497385](https://github.com/propulsion-ai/propulsionai-python/commit/1497385f1d57c619e88461cb055d5bce44788f7c))
* **api:** OpenAPI spec update via Stainless API ([#68](https://github.com/propulsion-ai/propulsionai-python/issues/68)) ([1e0a7aa](https://github.com/propulsion-ai/propulsionai-python/commit/1e0a7aaf5d57ef2c6f81bec99c3086f8f806bf2d))
* **api:** update via SDK Studio ([#59](https://github.com/propulsion-ai/propulsionai-python/issues/59)) ([d89297c](https://github.com/propulsion-ai/propulsionai-python/commit/d89297cbf0d392abb1157bff3d776e280cd68e3e))
* **api:** update via SDK Studio ([#64](https://github.com/propulsion-ai/propulsionai-python/issues/64)) ([f23575a](https://github.com/propulsion-ai/propulsionai-python/commit/f23575ad63f2e03953e1c594b0d67e0c136bac8e))
* **api:** update via SDK Studio ([#66](https://github.com/propulsion-ai/propulsionai-python/issues/66)) ([d4dddb5](https://github.com/propulsion-ai/propulsionai-python/commit/d4dddb548926551c94bca7284fc8dace8d5bd086))
* **api:** update via SDK Studio ([#69](https://github.com/propulsion-ai/propulsionai-python/issues/69)) ([ff0276f](https://github.com/propulsion-ai/propulsionai-python/commit/ff0276ffaed48896c237ace8883c8e01fc10d7f2))

## 0.1.0-alpha.12 (2024-07-24)

Full Changelog: [v0.1.0-alpha.11...v0.1.0-alpha.12](https://github.com/propulsion-ai/propulsionai-python/compare/v0.1.0-alpha.11...v0.1.0-alpha.12)

### Features

* add **/.DS_Store ([4808613](https://github.com/propulsion-ai/propulsionai-python/commit/4808613c64ec3014c94f63cab8de50f4b806978b))
* **api:** OpenAPI spec update via Stainless API ([#15](https://github.com/propulsion-ai/propulsionai-python/issues/15)) ([1b44c0f](https://github.com/propulsion-ai/propulsionai-python/commit/1b44c0f702364adcaee131b85efa107414c902e7))
* **api:** OpenAPI spec update via Stainless API ([#16](https://github.com/propulsion-ai/propulsionai-python/issues/16)) ([d56125f](https://github.com/propulsion-ai/propulsionai-python/commit/d56125fc8d38e10a8a1883b806e97bd7868e0a74))
* **api:** OpenAPI spec update via Stainless API ([#18](https://github.com/propulsion-ai/propulsionai-python/issues/18)) ([fdee4ba](https://github.com/propulsion-ai/propulsionai-python/commit/fdee4bad04a2d40d2325e75b1bbd7285647d2083))
* **api:** OpenAPI spec update via Stainless API ([#23](https://github.com/propulsion-ai/propulsionai-python/issues/23)) ([828e954](https://github.com/propulsion-ai/propulsionai-python/commit/828e954676813291c760ff43c3b69718661d2af7))
* **api:** OpenAPI spec update via Stainless API ([#25](https://github.com/propulsion-ai/propulsionai-python/issues/25)) ([7c77e0f](https://github.com/propulsion-ai/propulsionai-python/commit/7c77e0f2d32c04b0eab805ffac25f17b8cd18a7f))
* **api:** OpenAPI spec update via Stainless API ([#31](https://github.com/propulsion-ai/propulsionai-python/issues/31)) ([c6ee599](https://github.com/propulsion-ai/propulsionai-python/commit/c6ee5998a353045b5c2dab7a429b595e6c90ea1c))
* **api:** OpenAPI spec update via Stainless API ([#33](https://github.com/propulsion-ai/propulsionai-python/issues/33)) ([56bbd89](https://github.com/propulsion-ai/propulsionai-python/commit/56bbd894fe491f40dcfe9c2f7d6727b5d6651338))
* **api:** OpenAPI spec update via Stainless API ([#34](https://github.com/propulsion-ai/propulsionai-python/issues/34)) ([7423c8a](https://github.com/propulsion-ai/propulsionai-python/commit/7423c8a720f641986db2a0d2bc6da05baff76643))
* **api:** OpenAPI spec update via Stainless API ([#9](https://github.com/propulsion-ai/propulsionai-python/issues/9)) ([e046213](https://github.com/propulsion-ai/propulsionai-python/commit/e046213a1c0d4364061c88a07c7423fb464c1486))
* **api:** update via SDK Studio ([#1](https://github.com/propulsion-ai/propulsionai-python/issues/1)) ([8d1a074](https://github.com/propulsion-ai/propulsionai-python/commit/8d1a0742706ba9dd3726d98e7259fc93de858342))
* **api:** update via SDK Studio ([#11](https://github.com/propulsion-ai/propulsionai-python/issues/11)) ([663b080](https://github.com/propulsion-ai/propulsionai-python/commit/663b080ad6c60e2048e8d4e3f26f7760aa0e7ef3))
* **api:** update via SDK Studio ([#12](https://github.com/propulsion-ai/propulsionai-python/issues/12)) ([84db911](https://github.com/propulsion-ai/propulsionai-python/commit/84db9117c6f879aa4e33f1c86b2c18c86e8193fc))
* fix lint ([70f4730](https://github.com/propulsion-ai/propulsionai-python/commit/70f473069e06c494d8cdf11963ea3ab86b8b131c))
* fix linting errors ([ea7eefc](https://github.com/propulsion-ai/propulsionai-python/commit/ea7eefc6a392a0838fdbc78db4cc31e5041655eb))
* fix model endpoints manually ([b7039ed](https://github.com/propulsion-ai/propulsionai-python/commit/b7039ed1d96babc9d1dbc918f5a346c7d51c9682))
* fix ModelEpResponse ([ebf99be](https://github.com/propulsion-ai/propulsionai-python/commit/ebf99bef0ce027b98bdc73b754a115ee888d21a6))
* fix test ([2a4295e](https://github.com/propulsion-ai/propulsionai-python/commit/2a4295ede5c375f3d810b9d6b2f862b27a6ff049))
* fix test ([1670763](https://github.com/propulsion-ai/propulsionai-python/commit/167076335eb8be90d4393b1b5b317670db5e82b3))
* fix typechecking and imports ([b38ff7b](https://github.com/propulsion-ai/propulsionai-python/commit/b38ff7b7bc4105be89921a924e81546fad672be7))
* git pull origin release-please--branches--main--changes--next ([42222d9](https://github.com/propulsion-ai/propulsionai-python/commit/42222d92088604a3a0cad062968c257c8addf73a))
* gitignore ([d2da774](https://github.com/propulsion-ai/propulsionai-python/commit/d2da774e8badf1e0c170001bdcc2da0bed72a12e))
* lint ([056bc69](https://github.com/propulsion-ai/propulsionai-python/commit/056bc6909649bb75533b9240c65d82dfe0397467))


### Chores

* configure new SDK language ([7eb1613](https://github.com/propulsion-ai/propulsionai-python/commit/7eb1613247cdd64fdffd473b46353176f288344d))
* remove custom code ([9838415](https://github.com/propulsion-ai/propulsionai-python/commit/9838415023af7d17b460bc5b5c09c7b4faa8e113))
* remove custom code ([ee2f9cb](https://github.com/propulsion-ai/propulsionai-python/commit/ee2f9cba4f40ef5a5fc182301bb8e08221211255))
